---
title: NHN KCP 부가세 설정방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 부가세
seo:
  title: KCP 부가세 설정방법
  description: >-
    KCP는 계약 시 상점아이디(사이트코드)별 부가세 설정이 가능합니다. 사이트코드 과세 설정에 따라서 처리되는 과세/비과세 처리 부분을
    확인하시기 바랍니다.
  keywords:
    - 부가세
tags:
  - NHN KCP
  - 부가세
pgCompanies:
  - NHN KCP
searchTags:
  - KCP
  - NHNKCP
  - 복합과세
  - 면세
  - 비과세
  - 과세
  - 부가세
  - kcp 부가세
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="NHN KCP는 계약 시 상점아이디(사이트코드) 별로 부가세 설정을 할 수 있습니다. 
부가세 설정에 따른 적용기준을 안내드립니다." />

#### 1. 상점아이디(사이트코드)를 ‘면세’로 설정 > 거래 일괄 면세

면세로 설정된 MID로 결제를 하는 경우 지정하시는 파라미터(tax\_free)와 관계없이 KG이니시스 내부적으로 일괄 면세로 처리합니다.

#### 2. 상점아이디(사이트코드)를 ‘복합과세’로 설정 > 파라미터 값에 따라 처리

- 복합과세용 사이트코드 : 면세와과세 금액 결제를 동시에 진행할 수 있는 상점아이디로, \
  결제요청시마다 tax\_free 파라미터로 원하는만큼의 면세금액을 지정해서 보낼 수 있습니다.
- tax\_free 파라미터가 지정되지 않을 경우, 거래건 전액 ‘**과세**’로 반영됩니다.
